@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003, 2004, 2005 Free Software Foundation
+ * Copyright (C) 2003, 2004, 2005, 2007 Free Software Foundation
  *
  * Author: Nikos Mavroyanopoulos
  *
@@ -739,6 +739,25 @@ decode_pkcs8_key (const gnutls_datum_t * raw_key,
 
   if (result < 0)
     {
+      /* We've gotten this far. In the real world it's almost certain
+       * that we're dealing with a good file, but wrong password.
+       * Sadly like 90% of random data is somehow valid DER for the
+       * a first small number of bytes, so no easy way to guarantee. */
+      if (result == GNUTLS_E_ASN1_ELEMENT_NOT_FOUND ||
+	  result == GNUTLS_E_ASN1_IDENTIFIER_NOT_FOUND ||
+	  result == GNUTLS_E_ASN1_DER_ERROR ||
+	  result == GNUTLS_E_ASN1_VALUE_NOT_FOUND ||
+	  result == GNUTLS_E_ASN1_GENERIC_ERROR ||
+	  result == GNUTLS_E_ASN1_VALUE_NOT_VALID ||
+	  result == GNUTLS_E_ASN1_TAG_ERROR ||
+	  result == GNUTLS_E_ASN1_TAG_IMPLICIT ||
+	  result == GNUTLS_E_ASN1_TYPE_ANY_ERROR ||
+	  result == GNUTLS_E_ASN1_SYNTAX_ERROR ||
+	  result == GNUTLS_E_ASN1_DER_OVERFLOW)
+	{
+	  result = GNUTLS_E_DECRYPTION_FAILED;
+	}
+
       gnutls_assert ();
       goto error;
     }
@@ -779,6 +798,7 @@ decode_private_key_info (const gnutls_datum_t * der,
   if (result != ASN1_SUCCESS)
     {
       gnutls_assert ();
+      result = _gnutls_asn2err (result);
       goto error;
     }
 
